@@ -75,28 +75,46 @@ sub rewrite_rtconfig
 {
 
 	# database
-	$RT::DatabaseType   = 'SQLite';
-	$RT::DatabaseHost   = 'localhost';
-	$RT::DatabaseRTHost = 'localhost';
-	$RT::DatabasePort   = '';
-	$RT::DatabaseUser   = 'rt_user';
-	$RT::DatabasePassword = 'rt_pass';
-	$RT::DatabaseRequireSSL = undef;
-
+	config_set( '$DatabaseType'       , 'SQLite' );
+	config_set( '$DatabaseHost'       , 'localhost' );
+	config_set( '$DatabaseRTHost'     , 'localhost' );
+	config_set( '$DatabasePort'       , '' );
+	config_set( '$DatabaseUser'       , 'rt_user' );
+	config_set( '$DatabasePassword'   , 'rt_pass' );
+	config_set( '$DatabaseRequireSSL' , undef );
 	# database file name
-	$RT::DatabaseName = db_name();
+	config_set( '$DatabaseName'       , db_name() );
 
 	# generic logging
-	$RT::LogToSyslog = undef;
-	$RT::LogToScreen = undef;
-
+	config_set( '$LogToSyslog'    , undef );
+	config_set( '$LogToScreen'    , 'error' );
+	config_set( '$LogStackTraces' , 1 );
 	# logging to standalone file
-	$RT::LogToFile = 'debug';
-	my $dname = create_tmpdir();
-	my $fname = File::Spec->catfile($dname, test_name() .".log");
-	$RT::LogToFileNamed = $fname;
+	config_set( '$LogToFile'      , 'debug' );
+	my $fname = File::Spec->catfile(create_tmpdir(), test_name() .".log");
+	config_set( '$LogToFileNamed' , $fname );
 }
 
+=head3 config_set
+
+=cut
+
+*config_set = $RT::VERSION =~ /^3.7/? *config_set_new: *config_set_old;
+
+sub config_set_new {
+    my $opt = shift;
+    $opt =~ s/^[\$\%\@]// or warn "no leading sigil";
+    RT->Config->Set($opt, @_)
+}
+
+sub config_set_old
+{
+    my $opt = shift;
+    $opt =~ s/^([\$\%\@])/$1RT::/ or warn "no leading sigil in '$opt'";
+    eval "($opt) = (\@_);1" or warn "couldn't set option: $@";
+}
+
+
 =head2 DATABASES
 
 =head3 init_db
@@ -119,6 +137,8 @@ sub init_db
 	RT::ConnectToDatabase();
 	__init_schema( $RT::Handle->dbh );
 
+    require RT::CurrentUser;
+
 	__insert_initial_data();
 	RT::Init();
 	my $fname = File::Spec->catfile( $RT::EtcPath, 'initialdata' );
@@ -126,6 +146,8 @@ sub init_db
 	$fname = File::Spec->catfile( $RT::LocalEtcPath, 'initialdata' );
 	__insert_data( $fname ) if -f $fname && -r _;
 	RT::Init();
+	$SIG{__WARN__} = sub { $RT::Logger->warning( @_ ); warn @_ };
+	$SIG{__DIE__} = sub { $RT::Logger->crit( @_ ) unless $^S; die @_ };
 }
 
 sub __init_schema
@@ -358,6 +380,21 @@ sub connect_sqlite
 	return DBI->connect("dbi:SQLite:dbname=". shift, "", "");
 }
 
+=head2 SHREDDER
+
+=head3 shredder_new
+
+=cut
+
+sub shredder_new
+{
+    my $obj = new RTx::Shredder;
+    my $file = File::Spec->catfile( tmpdir(), test_name() .'.XXXX.sql' );
+    $obj->SetFile( FileName => $file, FromStorage => 0 );
+    return $obj;
+}
+
+
 =head2 TEST FILES
 
 =head3 test_name
@@ -393,6 +430,8 @@ Creates tmp dir if doesn't exist. Returns tmpdir absolute path.
 
 =cut
 
+sub create_tmpdir { my $n = tmpdir(); File::Path::mkpath( $n );	return $n }
+
 =head3 cleanup_tmp
 
 Delete all tmp files that match C<t/data/tmp/test_name.*> mask.
@@ -402,14 +441,10 @@ See also C<test_name> function.
 
 sub cleanup_tmp
 {
-	my $name = test_name();
-	my $dname = File::Spec->catdir(Cwd::cwd(), qw(t data tmp));
-	my $mask = File::Spec->catfile($dname, $name ) .'.*';
+	my $mask = File::Spec->catfile( tmpdir(), test_name() ) .'.*';
 	return unlink glob($mask);
 }
 
-sub create_tmpdir { my $n = tmpdir(); File::Path::mkpath( $n );	return $n; }
-
 =head2 SAVEPOINTS
 
 =head3 savepoint_name
@@ -430,34 +465,42 @@ sub savepoint_name
 Creates savepoint DB from the current.
 Takes name of the savepoint as argument.
 
+=head3 restore_savepoint
+
+Restores current DB to savepoint state.
+Takes name of the savepoint as argument.
+
 =cut
 
-sub create_savepoint
+sub create_savepoint { return __cp_db( db_name() => savepoint_name( shift ) ) }
+sub restore_savepoint { return __cp_db( savepoint_name( shift ) => db_name() ) }
+sub __cp_db
 {
-	my $orig = db_name();
-	my $dest = savepoint_name( shift );
+	my( $orig, $dest ) = @_;
 	$RT::Handle->dbh->disconnect;
-
-	# undef Handle to force reconnect
-	undef $RT::Handle;
+	# DIRTY HACK: undef Handles to force reconnect
+	$RT::Handle = undef;
+    %DBIx::SearchBuilder::DBIHandle = ();
+    $DBIx::SearchBuilder::PrevHandle = undef;
 
 	File::Copy::copy( $orig, $dest ) or die "Couldn't copy '$orig' => '$dest': $!";
-	RT::ConnectToDatabase;
+	RT::ConnectToDatabase();
 	return;
 }
 
+
 =head2 DUMPS
 
 =head3 dump_sqlite
 
 Returns DB dump as complex hash structure:
-{
+    {
 	TableName => {
 		#id => {
 			lc_field => 'value',
 		}
 	}
-}
+    }
 
 Takes named argument C<CleanDates>. If true clean all date fields from
 dump. True by default.
@@ -499,7 +542,7 @@ sub dump_current_and_savepoint
 	my $orig = savepoint_name( shift );
 	die "Couldn't find savepoint file" unless -f $orig && -r _;
 	my $odbh = connect_sqlite( $orig );
-	return ( dump_sqlite( $RT::Handle->dbh ), dump_sqlite( $odbh ) );
+	return ( dump_sqlite( $RT::Handle->dbh, @_ ), dump_sqlite( $odbh, @_ ) );
 }
 
 =head3 dump_savepoint_and_current
@@ -530,7 +573,7 @@ Function that return debug notes.
 
 =head3 note_on_fail
 
-Returns note about debug info you can find if test file fails.
+Returns note about debug info you can find if test failed.
 
 =cut
 
@@ -549,6 +592,21 @@ See also perldoc t/utils.pl to know how to use this info.
 END
 }
 
+=head3 note_not_patched
+
+Returns note about patch if RT looks like not patched.
+
+=cut
+
+sub note_not_patched
+{
+	return <<END;
+Couldn't find deleted ticket, may be you didn't patch
+your RT. Please, read README about how, when and why you
+have to patch your RT.
+END
+}
+
 =head2 OTHER
 
 =head3 is_all_seccessful
